@@ -2,7 +2,7 @@ package Net::GitHub;
 
 use Moose;
 
-our $VERSION = '0.11';
+our $VERSION = '0.12';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 sub new {
@@ -25,7 +25,7 @@ sub new {
 }
 
 no Moose;
-__PACKAGE__->meta->make_immutable;
+__PACKAGE__->meta->make_immutable(inline_constructor => 0);
 
 1;
 __END__
@@ -63,24 +63,30 @@ Read L<Net::GitHub::V2> for more details.
         login => 'fayland', token => '54b5197d7f92f52abc5c7149b313cf51', # faked
     );
     
+    # L<Net::GitHub::V2::Repositories>
     $github->repos->create( 'sandbox3', 'Sandbox desc', 'http://fayland.org/', 1 );
     $github->repos->show();
     
+    # L<Net::GitHub::V2::Users>
     my $followers = $github->user->followers();
     $github->user->update( name => 'Fayland Lam' );
     
+    # L<Net::GitHub::V2::Commits>
     my $commits = $github->commit->branch();
     my $commits = $github->commit->file( 'master', 'lib/Net/GitHub.pm' );
     my $co_detail = $github->commit->show( $sha1 );
     
+    # L<Net::GitHub::V2::Issues>
     my $issues = $github->issue->list('open');
     my $issue  = $github->issue->open( 'Bug title', 'Bug detail' );
     $github->issue->close( $number );
     
+    # L<Net::GitHub::V2::Object>
     my $tree = $github->obj_tree( $tree_sha1 );
     my $blob = $github->obj_blob( $tree_sha1, 'lib/Net/GitHub.pm' );
     my $raw  = $github->obj_raw( $sha1 );
     
+    # L<Net::GitHub::V2::Network>
     $github->network_meta;
     $github->network_data_chunk( $net_hash );
 
